Documentation
¶
Overview ¶
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Index ¶
- Variables
- type Counter
- type GenesisState
- func (*GenesisState) Descriptor() ([]byte, []int)deprecated
- func (x *GenesisState) GetCounters() []*Counter
- func (x *GenesisState) GetParams() *Params
- func (*GenesisState) ProtoMessage()
- func (x *GenesisState) ProtoReflect() protoreflect.Message
- func (x *GenesisState) Reset()
- func (x *GenesisState) String() string
- type Params
Constants ¶
This section is empty.
Variables ¶
var File_andgeer_checkers_v1_types_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Counter ¶
type Counter struct {
// count defines the count of the counter.
Count uint64 `protobuf:"varint,1,opt,name=count,proto3" json:"count,omitempty"`
// address defines the address that is associated with the count.
Address string `protobuf:"bytes,2,opt,name=address,proto3" json:"address,omitempty"`
// contains filtered or unexported fields
}
Counter defines a counter object. It is used only for genesis purposes. Collections does not need to use it.
func (*Counter) Descriptor
deprecated
func (*Counter) GetAddress ¶
func (*Counter) ProtoMessage ¶
func (*Counter) ProtoMessage()
func (*Counter) ProtoReflect ¶
func (x *Counter) ProtoReflect() protoreflect.Message
type GenesisState ¶
type GenesisState struct {
// counter defines the counter object.
Counters []*Counter `protobuf:"bytes,1,rep,name=counters,proto3" json:"counters,omitempty"`
// params defines all the parameters of the module.
Params *Params `protobuf:"bytes,2,opt,name=params,proto3" json:"params,omitempty"`
// contains filtered or unexported fields
}
GenesisState is the state that must be provided at genesis.
func (*GenesisState) Descriptor
deprecated
func (*GenesisState) Descriptor() ([]byte, []int)
Deprecated: Use GenesisState.ProtoReflect.Descriptor instead.
func (*GenesisState) GetCounters ¶
func (x *GenesisState) GetCounters() []*Counter
func (*GenesisState) GetParams ¶
func (x *GenesisState) GetParams() *Params
func (*GenesisState) ProtoMessage ¶
func (*GenesisState) ProtoMessage()
func (*GenesisState) ProtoReflect ¶
func (x *GenesisState) ProtoReflect() protoreflect.Message
func (*GenesisState) Reset ¶
func (x *GenesisState) Reset()
func (*GenesisState) String ¶
func (x *GenesisState) String() string
type Params ¶
type Params struct {
// contains filtered or unexported fields
}
Params defines the parameters of the module.
func (*Params) Descriptor
deprecated
func (*Params) ProtoMessage ¶
func (*Params) ProtoMessage()
func (*Params) ProtoReflect ¶
func (x *Params) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.